@@ -1,6 +1,6 @@
 # Library
 SDK_NAME = "unleash-client-python"
-SDK_VERSION = "3.5.1"
+SDK_VERSION = "3.6.0"
 REQUEST_TIMEOUT = 30
 METRIC_LAST_SENT_TIME = "mlst"
 
@@ -15,3 +15,6 @@ DISABLED_VARIATION = {
 REGISTER_URL = "/client/register"
 FEATURES_URL = "/client/features"
 METRICS_URL = "/client/metrics"
+
+# Cache keys
+FAILED_STRATEGIES = 'failed_strategies'
