@@ -1,13 +1,14 @@
 from fcache.cache import FileCache
 from UnleashClient.features.Feature import Feature
 from UnleashClient.variants.Variants import Variants
-from UnleashClient.constants import FEATURES_URL
+from UnleashClient.constants import FEATURES_URL, FAILED_STRATEGIES
 from UnleashClient.utils import LOGGER
 
 
 # pylint: disable=broad-except
 def _create_strategies(provisioning: dict,
-                       strategy_mapping: dict) -> list:
+                       strategy_mapping: dict,
+                       cache: FileCache) -> list:
     feature_strategies = []
 
     for strategy in provisioning["strategies"]:
@@ -26,16 +27,21 @@ def _create_strategies(provisioning: dict,
                 constraints=constraint_provisioning, parameters=strategy_provisioning
             ))
         except Exception as excep:
-            LOGGER.warning("Failed to load strategy. This may be a problem with a custom strategy. Exception: %s",
-                           excep)
+            if FAILED_STRATEGIES not in cache.keys():
+                cache[FAILED_STRATEGIES] = []  # Initialize cache key only if failures exist.
+
+            if strategy['name'] not in cache[FAILED_STRATEGIES]:
+                LOGGER.warning("Failed to load strategy. This may be a problem with a custom strategy. Exception: %s", excep)
+                cache[FAILED_STRATEGIES].append(strategy['name'])
 
     return feature_strategies
 
 
 def _create_feature(provisioning: dict,
-                    strategy_mapping: dict) -> Feature:
+                    strategy_mapping: dict,
+                    cache: FileCache) -> Feature:
     if "strategies" in provisioning.keys():
-        parsed_strategies = _create_strategies(provisioning, strategy_mapping)
+        parsed_strategies = _create_strategies(provisioning, strategy_mapping, cache)
     else:
         parsed_strategies = []
 
@@ -85,7 +91,7 @@ def load_features(cache: FileCache,
 
             feature_for_update.enabled = parsed_features[feature]["enabled"]
             if strategies:
-                parsed_strategies = _create_strategies(parsed_features[feature], strategy_mapping)
+                parsed_strategies = _create_strategies(parsed_features[feature], strategy_mapping, cache)
                 feature_for_update.strategies = parsed_strategies
 
             if 'variants' in parsed_features[feature]:
@@ -98,7 +104,7 @@ def load_features(cache: FileCache,
         new_features = list(set(feature_names) - set(feature_toggles.keys()))
 
         for feature in new_features:
-            feature_toggles[feature] = _create_feature(parsed_features[feature], strategy_mapping)
+            feature_toggles[feature] = _create_feature(parsed_features[feature], strategy_mapping, cache)
     except KeyError as cache_exception:
         LOGGER.warning("Cache Exception: %s", cache_exception)
         LOGGER.warning("Unleash client does not have cached features. "
